@@ -9,18 +9,27 @@ class GaussianBlur(BaseImageAugmentation):
     Stream processor which applies gaussian blur to images.
     """
 
-    sigma_from = TypedOption(
+    sigma_from: float = TypedOption(
         "-f", "--from-sigma",
         type=float,
         help="the minimum sigma for the blur to apply to the images"
     )
 
-    sigma_to = TypedOption(
+    sigma_to: float = TypedOption(
         "-t", "--to-sigma",
         type=float,
         help="the maximum sigma for the blur to apply to the images"
     )
 
+    def _default_suffix(self):
+        """
+        Returns the default suffix to use for images when using "add" rather than "replace" as mode.
+
+        :return: the default suffix
+        :rtype: str
+        """
+        return "-blurred"
+
     def _can_augment(self):
         """
         Checks whether augmentation can take place.
